@@ -2,6 +2,7 @@
 #' @description Creates a Kaplan-Meier plot with at risk tables below for survfit object.
 #' @param sfit a survfit object
 #' @param table logical: Create a table graphic below the K-M plot, indicating at-risk numbers?
+#' @param table.censor logical: Add numbers of censored in table graphic
 #' @param xlabs x-axis label
 #' @param ylabs y-axis label
 #' @param xlims numeric: list of min and max for x-axis. Default = c(0,max(sfit$time))
@@ -38,6 +39,7 @@
 #' @param nejm.infigure.ratiow Ratio of infigure width to total width, Default = 0.6
 #' @param nejm.infigure.ratioh Ratio of infigure height to total height, Default = 0.5
 #' @param nejm.infigure.ylim y-axis limit of infigure, Default = c(0,1)
+#' @param surv.by breaks unit in y-axis, default = NULL(ggplot default)
 #' @param ... PARAM_DESCRIPTION
 #' @return Plot
 #' @details DETAILS
@@ -85,6 +87,7 @@
 
 jskm <- function(sfit,
                  table = FALSE,
+                 table.censor = FALSE, 
                  xlabs = "Time-to-event",
                  ylabs = NULL,
                  xlims = c(0, max(sfit$time)),
@@ -121,13 +124,14 @@ jskm <- function(sfit,
                  nejm.infigure.ratiow = 0.6,
                  nejm.infigure.ratioh = 0.5,
                  nejm.infigure.ylim = c(0, 1),
+                 surv.by = NULL,
                  ...) {
   #################################
   # sorting the use of subsetting #
   #################################
-
+  
   n.risk <- n.censor <- surv <- strata <- lower <- upper <- NULL
-
+  
   times <- seq(0, max(sfit$time), by = timeby)
   if (!is.null(theme) && theme == "nejm") legendposition <- legendposition
   if (is.null(subs)) {
@@ -159,13 +163,13 @@ jskm <- function(sfit,
     subs2 <- which(regexpr(ssvar, summary(sfit, censored = T)$strata, perl = T) != -1)
     subs3 <- which(regexpr(ssvar, summary(sfit, times = times, extend = TRUE)$strata, perl = T) != -1)
   }
-
+  
   if (!is.null(subs) | !is.null(sfit$states)) pval <- FALSE
-
+  
   ##################################
   # data manipulation pre-plotting #
   ##################################
-
+  
   if (is.null(ylabs)) {
     if (cumhaz | !is.null(sfit$states)) {
       ylabs <- "Cumulative incidence"
@@ -173,7 +177,7 @@ jskm <- function(sfit,
       ylabs <- "Survival probability"
     }
   }
-
+  
   if (!is.null(status.cmprsk)) {
     if (length(levels(summary(sfit)$strata)) == 0) {
       # [subs1]
@@ -188,10 +192,11 @@ jskm <- function(sfit,
       if (is.null(ystratalabs)) {
         ystratalabs <- as.character("All")
       }
-      L <- summary(sfit)$table["0.95LCL"][[1]]
-      U <- summary(sfit)$table["0.95UCL"][[1]]
+      nc <- length(summary(sfit)$table)
+      L <- summary(sfit)$table[nc - 1][[1]]
+      U <- summary(sfit)$table[nc][[1]]
       median_time <- summary(sfit)$table["median"][[1]]
-      ystratalabs2 <- paste0(ystratalabs, " (median : ", median_time, ", 95%CI : ", L, "-", U, ")")
+      ystratalabs2 <- paste0(ystratalabs, " (median : ", median_time, ", ", sfit$conf.int * 100, "% CI : ", L, " - ", U, ")")
     } else {
       # [subs1]
       if (is.null(ystratalabs)) {
@@ -199,26 +204,27 @@ jskm <- function(sfit,
       }
       ystratalabs2 <- NULL
       for (i in 1:length(levels(summary(sfit)$strata))) {
-        L <- summary(sfit)$table[, "0.95LCL"][[i]]
-        U <- summary(sfit)$table[, "0.95UCL"][[i]]
+        nc <- ncol(summary(sfit)$table)
+        L <- summary(sfit)$table[, nc - 1][[i]]
+        U <- summary(sfit)$table[, nc][[i]]
         median_time <- summary(sfit)$table[, "median"][[i]]
-        ystratalabs2 <- c(ystratalabs2, paste0(ystratalabs[[i]], " (median : ", median_time, ", 95%CI : ", L, "-", U, ")"))
+        ystratalabs2 <- c(ystratalabs2, paste0(ystratalabs[[i]], " (median : ", median_time, ", ", sfit$conf.int * 100, "% CI : ", L, " - ", U, ")"))
       }
     }
   }
   if (is.null(ystrataname)) ystrataname <- "Strata"
   m <- max(nchar(ystratalabs))
   times <- seq(0, max(sfit$time), by = timeby)
-
+  
   if (length(levels(summary(sfit)$strata)) == 0) {
     Factor <- factor(rep("All", length(subs2)))
   } else {
     Factor <- factor(summary(sfit, censored = T)$strata[subs2], levels = names(sfit$strata))
   }
-
+  
   # Data to be used in the survival plot
-
-
+  
+  
   if (is.null(sfit$state)) { # no cmprsk
     df <- data.frame(
       time = sfit$time[subs2],
@@ -246,9 +252,9 @@ jskm <- function(sfit,
       lower = sfit$lower[, col.cmprsk][subs2]
     )
   }
-
+  
   form <- sfit$call$formula
-
+  
   if (!is.null(cut.landmark)) {
     if (is.null(data)) {
       data <- tryCatch(eval(sfit$call$data), error = function(e) e)
@@ -256,7 +262,7 @@ jskm <- function(sfit,
         stop("Landmark analysis requires data object. please input 'data' option")
       }
     }
-
+    
     var.time <- as.character(form[[2]][[2]])
     var.event <- as.character(form[[2]][[3]])
     if (length(var.event) > 1) {
@@ -268,23 +274,23 @@ jskm <- function(sfit,
     data1 <- data
     data1[[var.event]][data1[[var.time]] >= cut.landmark] <- 0
     data1[[var.time]][data1[[var.time]] >= cut.landmark] <- cut.landmark
-
+    
     sfit1 <- survfit(as.formula(form), data1)
     sfit2 <- survfit(as.formula(form), data[data[[var.time]] >= cut.landmark, ])
-
+    
     if (is.null(sfit$states)) {
       if (length(levels(Factor)) == 1) {
         df2 <- merge(subset(df, time >= cut.landmark)[, c("time", "n.risk", "n.event", "n.censor", "strata")],
-          data.frame(time = sfit2$time, surv = sfit2$surv, strata = "All", upper = sfit2$upper, lower = sfit2$lower),
-          by = c("time", "strata")
+                     data.frame(time = sfit2$time, surv = sfit2$surv, strata = "All", upper = sfit2$upper, lower = sfit2$lower),
+                     by = c("time", "strata")
         )
       } else {
         df2 <- merge(subset(df, time >= cut.landmark)[, c("time", "n.risk", "n.event", "n.censor", "strata")],
-          data.frame(time = sfit2$time, surv = sfit2$surv, strata = rep(names(sfit2$strata), sfit2$strata), upper = sfit2$upper, lower = sfit2$lower),
-          by = c("time", "strata")
+                     data.frame(time = sfit2$time, surv = sfit2$surv, strata = rep(names(sfit2$strata), sfit2$strata), upper = sfit2$upper, lower = sfit2$lower),
+                     by = c("time", "strata")
         )
       }
-
+      
       df11 <- rbind(subset(df, time < cut.landmark), df2[, names(df)])
       df <- rbind(df11, data.frame(time = cut.landmark, n.risk = summary(sfit, times = cut.landmark)$n.risk[[1]], n.event = 0, n.censor = 0, surv = 1, strata = levels(df$strata), upper = 1, lower = 1))
     } else {
@@ -292,24 +298,24 @@ jskm <- function(sfit,
         status.cmprsk <- sfit$states[2]
       }
       col.cmprsk <- which(sfit$state == status.cmprsk)
-
+      
       if (length(levels(Factor)) == 1) {
         df2 <- merge(subset(df, time >= cut.landmark)[, c("time", "n.risk", "n.event", "n.censor", "strata")],
-          data.frame(time = sfit2$time, surv = sfit2$pstate[, col.cmprsk], strata = "All", upper = sfit2$upper[, col.cmprsk], lower = sfit2$lower[, col.cmprsk]),
-          by = c("time", "strata")
+                     data.frame(time = sfit2$time, surv = sfit2$pstate[, col.cmprsk], strata = "All", upper = sfit2$upper[, col.cmprsk], lower = sfit2$lower[, col.cmprsk]),
+                     by = c("time", "strata")
         )
       } else {
         df2 <- merge(subset(df, time >= cut.landmark)[, c("time", "n.risk", "n.event", "n.censor", "strata")],
-          data.frame(time = sfit2$time, surv = sfit2$pstate[, col.cmprsk], strata = rep(names(sfit2$strata), sfit2$strata), upper = sfit2$upper[, col.cmprsk], lower = sfit2$lower[, col.cmprsk]),
-          by = c("time", "strata")
+                     data.frame(time = sfit2$time, surv = sfit2$pstate[, col.cmprsk], strata = rep(names(sfit2$strata), sfit2$strata), upper = sfit2$upper[, col.cmprsk], lower = sfit2$lower[, col.cmprsk]),
+                     by = c("time", "strata")
         )
       }
       df11 <- rbind(subset(df, time < cut.landmark), df2[, names(df)])
       df <- rbind(df11, data.frame(time = cut.landmark, n.risk = summary(sfit, times = cut.landmark)$n.risk[[1]], n.event = 0, n.censor = 0, surv = 0, strata = levels(df$strata), upper = 0, lower = 0))
     }
   }
-
-
+  
+  
   if (cumhaz & is.null(sfit$states)) {
     upper.new <- 1 - df$lower
     lower.new <- 1 - df$upper
@@ -317,7 +323,7 @@ jskm <- function(sfit,
     df$lower <- lower.new
     df$upper <- upper.new
   }
-
+  
   # Final changes to data for survival plot
   levels(df$strata) <- ystratalabs
   zeros <- data.frame(
@@ -330,37 +336,37 @@ jskm <- function(sfit,
     zeros$lower <- 0
     zeros$upper <- 0
   }
-
+  
   df <- rbind(zeros, df)
   d <- length(levels(df$strata))
-
+  
   ###################################
   # specifying axis parameteres etc #
   ###################################
-
+  
   if (dashed == TRUE | all(linecols == "black")) {
     linetype <- c("solid", "dashed", "dotted", "dotdash", "longdash", "twodash", "1F", "F1", "4C88C488", "12345678")
   } else {
     linetype <- c("solid", "solid", "solid", "solid", "solid", "solid", "solid", "solid", "solid", "solid", "solid")
   }
-
+  
   # Scale transformation
   # ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
   surv.scale <- match.arg(surv.scale)
   scale_labels <- ggplot2::waiver()
   if (surv.scale == "percent") scale_labels <- scales::percent
-
+  
   p <- ggplot2::ggplot(df, aes(x = time, y = surv, colour = strata, linetype = strata)) +
     ggtitle(main)
-
-
+  
+  
   linecols2 <- linecols
   if (all(linecols == "black")) {
     linecols <- "Set1"
     p <- ggplot2::ggplot(df, aes(x = time, y = surv, linetype = strata)) +
       ggtitle(main)
   }
-
+  
   # Set up theme elements
   p <- p + theme_bw() +
     theme(
@@ -376,13 +382,18 @@ jskm <- function(sfit,
       axis.line.x = element_line(linewidth = 0.5, linetype = "solid", colour = "black"),
       axis.line.y = element_line(linewidth = 0.5, linetype = "solid", colour = "black")
     ) +
-    scale_x_continuous(xlabs, breaks = times, limits = xlims) +
-    scale_y_continuous(ylabs, limits = ylims, labels = scale_labels)
-
-
-
-
-
+    scale_x_continuous(xlabs, breaks = times, limits = xlims)
+  
+  if (!is.null(surv.by)) {
+    p <- p + scale_y_continuous(ylabs, limits = ylims, labels = scale_labels, breaks = seq(ylims[1], ylims[2], by = surv.by))
+  } else {
+    p <- p + scale_y_continuous(ylabs, limits = ylims, labels = scale_labels)
+  }
+  
+  
+  
+  
+  
   if (!is.null(theme) && theme == "jama") {
     p <- p + theme(
       panel.grid.major.x = element_blank()
@@ -392,13 +403,13 @@ jskm <- function(sfit,
       panel.grid.major = element_blank()
     )
   }
-
-
+  
+  
   # Removes the legend:
   if (legend == FALSE) {
     p <- p + guides(colour = "none", linetype = "none")
   }
-
+  
   # Add lines too plot
   if (is.null(cut.landmark)) {
     if (med == T & is.null(status.cmprsk)) {
@@ -419,13 +430,13 @@ jskm <- function(sfit,
         geom_step(data = subset(df, time >= cut.landmark), linewidth = linewidth) + geom_step(data = subset(df, time < cut.landmark), linewidth = linewidth)
     }
   }
-
+  
   brewer.palette <- c(
     "BrBG", "PiYG", "PRGn", "PuOr", "RdBu", "RdGy", "RdYlBu", "RdYlGn", "Spectral", "Accent", "Dark2", "Paired", "Pastel1", "Pastel2",
     "Set1", "Set2", "Set3", "Blues", "BuGn", "BuPu", "GnBu", "Greens", "Greys", "Oranges", "OrRd", "PuBu", "PuBuGn", "PuRd", "Purples",
     "RdPu", "Reds", "YlGn", "YlGnBu", "YlOrBr", "YlOrRd"
   )
-
+  
   if (!is.null(theme) && theme == "jama") {
     col.pal <- c("#00AFBB", "#E7B800", "#FC4E07")
     col.pal <- rep(col.pal, ceiling(length(ystratalabs) / 3))
@@ -435,8 +446,8 @@ jskm <- function(sfit,
     col.pal <- linecols
     col.pal <- rep(col.pal, ceiling(length(ystratalabs) / length(linecols)))
   }
-
-
+  
+  
   if (is.null(cut.landmark)) {
     if (med == T & is.null(status.cmprsk)) {
       if (is.null(col.pal)) {
@@ -466,15 +477,15 @@ jskm <- function(sfit,
       }
     }
   }
-
+  
   # Add censoring marks to the line:
   if (marks == TRUE) {
     p <- p + geom_point(data = subset(df, n.censor >= 1), aes(x = time, y = surv, colour = strata), shape = shape)
   }
-
+  
   # Add median value
-
-
+  
+  
   if (med == TRUE & is.null(cut.landmark) & is.null(status.cmprsk)) {
     if (length(levels(summary(sfit)$strata)) == 0) {
       median_time <- summary(sfit)$table["median"][[1]]
@@ -493,7 +504,7 @@ jskm <- function(sfit,
       }
     }
   }
-
+  
   if (med == TRUE & !is.null(cut.landmark) & is.null(status.cmprsk)) {
     if (length(levels(summary(sfit)$strata)) == 0) {
       median_time <- summary(sfit1)$table[, "median"][[1]]
@@ -517,9 +528,9 @@ jskm <- function(sfit,
       }
     }
   }
-
-
-
+  
+  
+  
   # Add 95% CI to plot
   if (ci == TRUE) {
     if (med == FALSE | !is.null(status.cmprsk) | (!is.null(theme) && theme == "nejm")) {
@@ -540,11 +551,11 @@ jskm <- function(sfit,
       }
     }
   }
-
-
-
-
-
+  
+  
+  
+  
+  
   if (!is.null(cut.landmark)) {
     p <- p + geom_vline(xintercept = cut.landmark, lty = 2)
   }
@@ -579,8 +590,8 @@ jskm <- function(sfit,
       }
     }
   }
-
-
+  
+  
   ## Create a blank plot for place-holding
   blank.pic <- ggplot(df, aes(time, surv)) +
     geom_blank() +
@@ -591,14 +602,14 @@ jskm <- function(sfit,
       axis.ticks = element_blank(),
       panel.grid.major = element_blank(), panel.border = element_blank()
     )
-
+  
   #####################
   # p-value placement #
   ##################### a
-
+  
   if (length(levels(summary(sfit)$strata)) == 0) pval <- F
   # if(!is.null(cut.landmark)) pval <- F
-
+  
   if (pval == TRUE) {
     if (is.null(data)) {
       data <- tryCatch(eval(sfit$call$data), error = function(e) e)
@@ -606,11 +617,11 @@ jskm <- function(sfit,
         stop("'pval' option requires data object. please input 'data' option")
       }
     }
-
+    
     if (is.null(cut.landmark)) {
       sdiff <- survival::survdiff(as.formula(form), data = data)
       pvalue <- pchisq(sdiff$chisq, length(sdiff$n) - 1, lower.tail = FALSE)
-
+      
       ## cluster option
       if (cluster.option == "cluster" & !is.null(cluster.var)) {
         form.old <- as.character(form)
@@ -623,10 +634,10 @@ jskm <- function(sfit,
         sdiff <- survival::coxph(as.formula(form.new), data = data, model = T)
         pvalue <- summary(sdiff)$logtest["pvalue"]
       }
-
+      
       pvaltxt <- ifelse(pvalue < 0.001, "p < 0.001", paste("p =", round(pvalue, 3)))
       if (pval.testname) pvaltxt <- paste0(pvaltxt, " (Log-rank)")
-
+      
       # MOVE P-VALUE LEGEND HERE BELOW [set x and y]
       if (is.null(pval.coord)) {
         p <- p + annotate("text", x = (as.integer(max(sfit$time) / 5)), y = 0.1 + ylims[1], label = pvaltxt, size = pval.size)
@@ -639,7 +650,7 @@ jskm <- function(sfit,
       pvalue <- sapply(list(sdiff1, sdiff2), function(x) {
         pchisq(x$chisq, length(x$n) - 1, lower.tail = FALSE)
       })
-
+      
       ## cluster option
       if (cluster.option == "cluster" & !is.null(cluster.var)) {
         form.old <- as.character(form)
@@ -658,11 +669,11 @@ jskm <- function(sfit,
           summary(x)$logtest["pvalue"]
         })
       }
-
+      
       pvaltxt <- ifelse(pvalue < 0.001, "p < 0.001", paste("p =", round(pvalue, 3)))
-
+      
       if (pval.testname) pvaltxt <- paste0(pvaltxt, " (Log-rank)")
-
+      
       if (is.null(pval.coord)) {
         p <- p + annotate("text", x = c(as.integer(max(sfit$time) / 10), as.integer(max(sfit$time) / 10) + cut.landmark), y = 0.1 + ylims[1], label = pvaltxt, size = pval.size)
       } else {
@@ -670,27 +681,37 @@ jskm <- function(sfit,
       }
     }
   }
-
+  
   ###################################################
   # Create table graphic to include at-risk numbers #
   ###################################################
-
+  
   n.risk <- NULL
   if (length(levels(summary(sfit)$strata)) == 0) {
     Factor <- factor(rep("All", length(subs3)))
   } else {
     Factor <- factor(summary(sfit, times = times, extend = TRUE)$strata[subs3])
   }
-
+  
   if (table == TRUE) {
     risk.data <- data.frame(
       strata = Factor,
       time = summary(sfit, times = times, extend = TRUE)$time[subs3],
       n.risk = summary(sfit, times = times, extend = TRUE)$n.risk[subs3]
     )
-
+    if(table.censor){
+      risk.data <- data.frame(
+        strata = Factor,
+        time = summary(sfit, times = times, extend = TRUE)$time[subs3],
+        n.risk = summary(sfit, times = times, extend = TRUE)$n.risk[subs3],
+        n.censor = summary(sfit, times = times, extend = TRUE)$n.censor[subs3]
+      )
+      risk.data$n.risk <- paste0(risk.data$n.risk, " (", risk.data$n.censor, ")")
+      risk.data$n.censor <- NULL
+    }
+    print(risk.data)
     risk.data$strata <- factor(risk.data$strata, levels = rev(levels(risk.data$strata)))
-
+    
     data.table <- ggplot(risk.data, aes(x = time, y = strata, label = format(n.risk, nsmall = 0))) +
       geom_text(size = 3.5) +
       theme_bw() +
@@ -707,31 +728,31 @@ jskm <- function(sfit,
       )
     data.table <- data.table +
       guides(colour = "none", linetype = "none") + xlab(NULL) + ylab(NULL)
-
-
+    
+    
     # ADJUST POSITION OF TABLE FOR AT RISK
     data.table <- data.table +
       theme(plot.margin = unit(c(-1.5, 1, 0.1, ifelse(m < 10, 3.1, 4.3) - 0.38 * m), "lines"))
   }
-
-
+  
+  
   #######################
   # Plotting the graphs #
   #######################
-
+  
   if (!is.null(theme) && theme == "nejm") {
     p2 <- p1 + coord_cartesian(ylim = nejm.infigure.ylim) + theme(
       axis.title.x = element_blank(), axis.title.y = element_blank(),
       axis.text = element_text(size = 10 * nejm.infigure.ratiow),
-    ) + guides(colour = "none", linetype = "none")
+    ) + guides(colour = "none", linetype = "none") + scale_y_continuous(limits = nejm.infigure.ylim, breaks = waiver(), labels = scale_labels)
     p <- p + patchwork::inset_element(p2, 1 - nejm.infigure.ratiow, 1 - nejm.infigure.ratioh, 1, 1, align_to = "panel")
   }
-
+  
   if (table == TRUE) {
     ggpubr::ggarrange(p, blank.pic, data.table,
-      nrow = 3,
-      # align = "v",
-      heights = c(2, .1, .25)
+                      nrow = 3,
+                      # align = "v",
+                      heights = c(2, .1, .25)
     )
   } else {
     p
